## frontend

The frontend service is responsible for providing the interface to load utk. This service and the utk service are completely independent. Both of them acess `/utk-bundle` where utk stores the bundled application and frontend consume the bundle to embed it in a React powered page. 

Some folders under `src/` like `caveSupport/`, `pythonComponents`, `utilities` are legacy features that are not integrated yet.  

### docker-compose.yml

- The service is acessible through `localhost:3000`.
- `WATCHPACK_POLLING` is used to hot reload the application.
- `REACT_APP_BACKEND_SERVICE_URL` indicates the location of the backend service.
- This service depends on backend to consume the grammar from `/data` and utk to consume the bundle generated by it. 